==> open-xchange-core_7.10.4.orig.tar.bz2: open-xchange-core-7.10.4/com.openexchange.rest.services/src/com/openexchange/rest/services/annotation/Role.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.rest.services.annotation;

/**
 * {@link Role} - An enumeration for known security roles for REST end-points. A security role specifies how access to a certain REST
 * end-point is granted.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.8.3
 */
public enum Role {

    /**
     * The role identifier for {@link com.openexchange.rest.services.annotation.RoleAllowed} annotation and
     * {@link javax.annotation.security.RolesAllowed} annotation respectively signaling to perform basic-auth.
     * <p>
     * Properties <code>"com.openexchange.rest.services.basic-auth.login"</code> and
     * <code>"com.openexchange.rest.services.basic-auth.password"</code> are required to be set.
     */
    BASIC_AUTHENTICATED("Basic-Authenticated"),
    /**
     * The role identifier for {@link com.openexchange.rest.services.annotation.RoleAllowed} annotation and
     * {@link javax.annotation.security.RolesAllowed} annotation respectively allowing end-point-specific basic-auth.
     * <p>
     * <div style="margin-left: 0.1in; margin-right: 0.5in; margin-bottom: 0.1in; background-color:#FFDDDD;">
     * The concrete REST end-point is supposed to implement interface <code>com.openexchange.rest.services.EndpointAuthenticator</code>.
     * </div>
     */
    INDIVIDUAL_BASIC_AUTHENTICATED("Individual-Basic-Authenticated"),
    /**
     * The role identifier for {@link com.openexchange.rest.services.annotation.RoleAllowed} annotation and
     * {@link javax.annotation.security.RolesAllowed} annotation respectively signaling to perform basic-auth
     * against the Open-Xchange Server's master administrator credentials (the ones specified in <code>"mpasswd"</code> file).
     */
    MASTER_ADMIN_AUTHENTICATED("Master-Admin-Basic-Authenticated"),

    ;

    private final String id;

    private Role(String id) {
        this.id = id;
    }

    /**
     * Gets the role identifier.
     *
     * @return The role identifier
     */
    public String getId() {
        return id;
    }
}

==> open-xchange-core_7.10.5.orig.tar.bz2: open-xchange-core-7.10.5/com.openexchange.rest.services/src/com/openexchange/rest/services/annotation/Role.java <==
/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.rest.services.annotation;

/**
 * {@link Role} - An enumeration for known security roles for REST end-points. A security role specifies how access to a certain REST
 * end-point is granted.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.8.3
 */
public enum Role {

    /**
     * The role identifier for {@link com.openexchange.rest.services.annotation.RoleAllowed} annotation and
     * {@link javax.annotation.security.RolesAllowed} annotation respectively signalling to perform basic-auth.
     * <p>
     * Properties <code>"com.openexchange.rest.services.basic-auth.login"</code> and
     * <code>"com.openexchange.rest.services.basic-auth.password"</code> are required to be set.
     */
    BASIC_AUTHENTICATED("Basic-Authenticated"),
    /**
     * The role identifier for {@link com.openexchange.rest.services.annotation.RoleAllowed} annotation and
     * {@link javax.annotation.security.RolesAllowed} annotation respectively allowing end-point-specific basic-auth.
     * <p>
     * <div style="margin-left: 0.1in; margin-right: 0.5in; margin-bottom: 0.1in; background-color:#FFDDDD;">
     * The concrete REST end-point is supposed to implement interface <code>com.openexchange.rest.services.EndpointAuthenticator</code>.
     * </div>
     */
    INDIVIDUAL_BASIC_AUTHENTICATED("Individual-Basic-Authenticated"),
    /**
     * The role identifier for {@link com.openexchange.rest.services.annotation.RoleAllowed} annotation and
     * {@link javax.annotation.security.RolesAllowed} annotation respectively signalling to perform basic-auth
     * against the Open-Xchange Server's master administrator credentials (the ones specified in <code>"mpasswd"</code> file).
     */
    MASTER_ADMIN_AUTHENTICATED("Master-Admin-Basic-Authenticated"),

    ;

    private final String id;

    private Role(String id) {
        this.id = id;
    }

    /**
     * Gets the role identifier.
     *
     * @return The role identifier
     */
    public String getId() {
        return id;
    }
}
